@@ -16,18 +16,17 @@ import getpass
 from quantrocket.houston import houston
 from quantrocket.cli.utils.output import json_to_cli
 
-def list_databases(service=None, codes=None, detail=False, expand=False):
+def list_databases(services=None, codes=None, detail=False, expand=False):
     """
     List databases.
 
     Parameters
     ----------
-    service : str, optional
-        only list databases for this service
+    services : str, optional
+        limit to these services
 
     codes: list of str, optional
-        only list databases identified by these codes (omit to list all databases
-        for service)
+        limit to these codes
 
     detail : bool
         return database statistics (default is to return a
@@ -39,26 +38,29 @@ def list_databases(service=None, codes=None, detail=False, expand=False):
 
     Returns
     -------
-    list
-        list of databases
+    dict
+        dict of lists of databases (one key for PostgreSQL databases and one for
+        SQLite databases)
 
     Examples
     --------
     Load database details in a pandas DataFrame:
 
     >>> from quantrocket.db import list_databases
+    >>> import itertools
     >>> databases = list_databases(detail=True)
-    >>> databases = pd.DataFrame.from_records(databases)
+    >>> databases = pd.DataFrame.from_records(itertools.chain(databases["sqlite"], databases["postgres"]))
     """
     params = {}
-    if service:
-        params["service"] = service
+    if services:
+        params["services"] = services
     if codes:
         params["codes"] = codes
     if detail:
         params["detail"] = detail
     if expand:
         params["expand"] = expand
+
     response = houston.get("/db/databases", params=params)
     houston.raise_for_status_with_json(response)
     return response.json()
@@ -66,32 +68,6 @@ def list_databases(service=None, codes=None, detail=False, expand=False):
 def _cli_list_databases(*args, **kwargs):
     return json_to_cli(list_databases, *args, **kwargs)
 
-def download_database(database, outfile):
-    """
-    Download a database from the db service and write to a local file.
-
-    Parameters
-    ----------
-    database : str, required
-        the filename of the database (as returned by the list_databases)
-
-    outfile: str, required
-        filename to write the database to
-
-    Returns
-    -------
-    None
-    """
-    response = houston.get("/db/databases/{0}".format(database), stream=True)
-    houston.raise_for_status_with_json(response)
-    with open(outfile, "wb") as f:
-        for chunk in response.iter_content(chunk_size=1024):
-            if chunk:
-                f.write(chunk)
-
-def _cli_download_database(*args, **kwargs):
-    return json_to_cli(download_database, *args, **kwargs)
-
 def get_s3_config():
     """
     Return the current S3 configuration, if any.
@@ -117,6 +93,8 @@ def set_s3_config(access_key_id=None, secret_access_key=None, bucket=None):
 
     See http://qrok.it/h/dbs3 to learn more.
 
+    Credentials are encrypted at rest and never leave your deployment.
+
     Parameters
     ----------
     access_key_id : str, optional
@@ -156,7 +134,7 @@ def _cli_get_or_set_s3_config(access_key_id=None, secret_access_key=None,
     else:
         return json_to_cli(get_s3_config, *args, **kwargs)
 
-def s3_push_databases(service, codes=None):
+def s3_push_databases(services=None, codes=None):
     """
     Push database(s) to Amazon S3.
 
@@ -164,30 +142,30 @@ def s3_push_databases(service, codes=None):
 
     Parameters
     ----------
-    serivce : str, required
-        only push databases for this service (specify 'all' to
-        push all services)
+    serivces : list of str, optional
+        limit to these services
 
     codes: list of str, optional
-        only push databases identified by these codes (omit to
-        push all databases for service)
+        limit to these codes
 
     Returns
     -------
     json
         status message
     """
-    data = {}
+    params = {}
+    if services:
+        params["services"] = services
     if codes:
-        data["codes"] = codes
-    response = houston.put("/db/s3/{0}".format(service), data=data)
+        params["codes"] = codes
+    response = houston.put("/db/s3", params=params)
     houston.raise_for_status_with_json(response)
     return response.json()
 
 def _cli_s3_push_databases(*args, **kwargs):
     return json_to_cli(s3_push_databases, *args, **kwargs)
 
-def s3_pull_databases(service, codes=None, force=False):
+def s3_pull_databases(services=None, codes=None, force=False):
     """
     Pull database(s) from Amazon S3.
 
@@ -195,13 +173,11 @@ def s3_pull_databases(service, codes=None, force=False):
 
     Parameters
     ----------
-    serivce : str, required
-        only pull databases for this service (specify 'all' to
-        pull all services)
+    serivces : list of str, optional
+        limit to these services
 
     codes: list of str, optional
-        only pull databases identified by these codes (omit to
-        pull all databases for service)
+        limit to these codes
 
     force: bool
         overwrite existing database if one exists (default is to
@@ -213,43 +189,45 @@ def s3_pull_databases(service, codes=None, force=False):
         status message
     """
     params = {}
+    if services:
+        params["services"] = services
     if codes:
         params["codes"] = codes
     if force:
         params["force"] = force
-    response = houston.get("/db/s3/{0}".format(service), params=params)
+    response = houston.get("/db/s3", params=params)
     houston.raise_for_status_with_json(response)
     return response.json()
 
 def _cli_s3_pull_databases(*args, **kwargs):
     return json_to_cli(s3_pull_databases, *args, **kwargs)
 
-def optimize_databases(service, codes=None):
+def optimize_databases(services=None, codes=None):
     """
-    Optimize database file(s) to improve performance.
+    Optimize databases to improve performance.
 
-    This runs SQLite's 'VACUUM' command, which defragments the .sqlite file
-    and reclaims disk space.
+    This runs the 'VACUUM' command, which defragments the database and
+    reclaims disk space.
 
     Parameters
     ----------
-    serivce : str, required
-        only optimize databases for this service (specify 'all' to
-        optimize all services)
+    serivces : list of str, optional
+        limit to these service
 
     codes: list of str, optional
-        only optimize databases identified by these codes (omit to
-        optimize all databases for service)
+        limit to these codes
 
     Returns
     -------
     json
         status message
     """
-    data = {}
+    params = {}
     if codes:
-        data["codes"] = codes
-    response = houston.post("/db/optimizations/{0}".format(service), data=data)
+        params["codes"] = codes
+    if services:
+        params["services"] = services
+    response = houston.post("/db/optimizations", params=params)
     houston.raise_for_status_with_json(response)
     return response.json()
 
